Changelog
=========


1.0.0 (2019-05-14)
------------------

- Python 3 compatibility.
  [timo]

- Plone 5.2 compatibility.
  [timo]

- Remove unnecessary plone.directives.form test dependency.
  [timo]

- Use black formatter.
  [timo]


1.0.0a1 (2018-07-09)
--------------------

- Initial release.
  [kitconcept]
